@@ -7,7 +7,6 @@ from typing import Any
 
 from pdm.pep517._vendor import toml
 from pdm.pep517.base import Builder
-from pdm.pep517.utils import safe_version, to_filename
 
 
 def normalize_file_permissions(st_mode: int) -> int:
@@ -52,15 +51,13 @@ class SdistBuilder(Builder):
         if not os.path.exists(build_dir):
             os.makedirs(build_dir, exist_ok=True)
 
-        version = to_filename(safe_version(self.meta.version))
+        version = self.meta_version
 
-        target = os.path.join(
-            build_dir, "{}-{}.tar.gz".format(self.meta.project_name, version)
-        )
+        target = os.path.join(build_dir, f"{self.meta.project_name}-{version}.tar.gz")
         tar = tarfile.open(target, mode="w:gz", format=tarfile.PAX_FORMAT)
 
         try:
-            tar_dir = "{}-{}".format(self.meta.project_name, version)
+            tar_dir = f"{self.meta.project_name}-{version}"
 
             files_to_add = self.find_files_to_add(True)
 
@@ -93,8 +90,9 @@ class SdistBuilder(Builder):
         This is mainly aiming at fixing the version number in pyproject.toml
         """
         pyproject = toml.loads(self.meta.filepath.read_text("utf-8"))
-        if not isinstance(self.meta._metadata.get("version", ""), str):
+        if self.meta.dynamic and "version" in self.meta.dynamic:
             self.meta._metadata["version"] = self.meta.version
+            self.meta._metadata["dynamic"].remove("version")
         pyproject["project"] = self.meta._metadata
         name = self.meta.filepath.name
         tarinfo = tar.gettarinfo(name, os.path.join(tar_dir, name))
