@@ -7,7 +7,7 @@ from contextlib import contextmanager
 from fnmatch import fnmatchcase
 from pathlib import Path
 from sysconfig import get_config_var
-from typing import Callable, Generator, Iterable, Optional
+from typing import Any, Callable, Generator, Iterable, Optional
 
 from pdm.pep517._vendor.packaging import tags
 from pdm.pep517._vendor.packaging.markers import Marker
@@ -84,7 +84,7 @@ def find_packages_iter(
         return lambda name: any(fnmatchcase(name, pat=pat) for pat in patterns)
 
     fexclude, finclude = _build_filter(exclude), _build_filter(include)
-    for root, dirs, files in os.walk(where, followlinks=True):
+    for root, dirs, _files in os.walk(where, followlinks=True):
         # Copy dirs to iterate over it, then empty dirs.
         all_dirs = dirs[:]
         dirs[:] = []
@@ -120,13 +120,13 @@ def cd(path: str) -> Generator[None, None, None]:
         os.chdir(_old_cwd)
 
 
-def normalize_path(filename: os.PathLike) -> str:
+def normalize_path(filename: "os.PathLike[Any]") -> str:
     """Normalize a file/dir name for comparison purposes"""
     filename = os.path.abspath(filename) if sys.platform == "cygwin" else filename
     return os.path.normcase(os.path.realpath(os.path.normpath(filename)))
 
 
-def get_platform(build_dir: os.PathLike) -> str:
+def get_platform(build_dir: "os.PathLike[Any]") -> str:
     """Return our platform name 'win32', 'linux_x86_64'"""
     result = distutils.util.get_platform()
     if result.startswith("macosx") and os.path.exists(build_dir):
@@ -146,7 +146,7 @@ def get_flag(
     if val is None:
         if warn:
             warnings.warn(
-                "Config variable '{0}' is unset, Python ABI tag may "
+                "Config variable '{}' is unset, Python ABI tag may "
                 "be incorrect".format(var),
                 RuntimeWarning,
                 2,
@@ -175,7 +175,7 @@ def get_abi_tag() -> Optional[str]:
             "Py_UNICODE_SIZE", sys.maxunicode == 0x10FFFF, expected=4, warn=is_cpython
         ):
             u = "u"
-        return "%s%s%s%s%s" % (impl, tags.interpreter_version(), d, m, u)
+        return f"{impl}{tags.interpreter_version()}{d}{m}{u}"
     elif soabi and soabi.startswith("cpython-"):
         return "cp" + soabi.split("-")[1]
     elif soabi:
