@@ -18,13 +18,13 @@ from pdm.pep517 import __version__
 from pdm.pep517._vendor.packaging import tags
 from pdm.pep517._vendor.packaging.specifiers import SpecifierSet
 from pdm.pep517.base import Builder, BuildError
-from pdm.pep517.utils import get_abi_tag, get_platform, safe_version, to_filename
+from pdm.pep517.utils import get_abi_tag, get_platform
 
 WHEEL_FILE_FORMAT = (
     """\
 Wheel-Version: 1.0
 Generator: pdm-pep517 %s
-Root-Is-Purelib: {pure_lib}
+Root-Is-Purelib: {is_purelib}
 Tag: {tag}
 """
     % __version__
@@ -84,15 +84,15 @@ class WheelBuilder(Builder):
 
     @property
     def wheel_filename(self) -> str:
-        name = to_filename(self.meta.project_name)
-        version = to_filename(safe_version(self.meta.version))
+        name = self.meta.project_filename
+        version = self.meta_version
         return f"{name}-{version}-{self.tag}.whl"
 
     @property
     def tag(self) -> str:
         platform = self.plat_name
         impl = self.python_tag
-        if self.meta.build:
+        if not self.meta.is_purelib:
             if not platform:
                 platform = get_platform(self.location / "build")
             if not impl:
@@ -116,7 +116,7 @@ class WheelBuilder(Builder):
 
         platform = platform.lower().replace("-", "_").replace(".", "_")
         tag = (impl, abi_tag, platform)
-        if self.meta.build:
+        if not self.meta.is_purelib:
             supported_tags = [(t.interpreter, t.abi, platform) for t in tags.sys_tags()]
             assert (
                 tag in supported_tags
@@ -125,8 +125,8 @@ class WheelBuilder(Builder):
 
     @property
     def dist_info_name(self) -> str:
-        name = to_filename(self.meta.project_name)
-        version = to_filename(safe_version(self.meta.version))
+        name = self.meta.project_filename
+        version = self.meta_version
         return f"{name}-{version}.dist-info"
 
     def _write_record(self, fp: TextIO) -> None:
@@ -260,16 +260,13 @@ class WheelBuilder(Builder):
 
     def _write_wheel_file(self, fp: TextIO) -> None:
         fp.write(
-            WHEEL_FILE_FORMAT.format(
-                pure_lib=self.meta.build is None,
-                tag=self.tag,
-            )
+            WHEEL_FILE_FORMAT.format(is_purelib=self.meta.is_purelib, tag=self.tag)
         )
 
     def _write_entry_points(self, fp: TextIO) -> None:
         entry_points = self.meta.entry_points
         for group_name in sorted(entry_points):
-            fp.write("[{}]\n".format(group_name))
+            fp.write(f"[{group_name}]\n")
             for ep in sorted(entry_points[group_name]):
                 fp.write(ep.replace(" ", "") + "\n")
 
