@@ -1,5 +1,6 @@
 import email
 import zipfile
+from pathlib import Path
 
 import pytest
 
@@ -7,7 +8,7 @@ from pdm.pep517 import api
 from tests.testutils import build_fixture_project, get_tarball_names, get_wheel_names
 
 
-def test_build_single_module(tmp_path):
+def test_build_single_module(tmp_path: Path) -> None:
     with build_fixture_project("demo-module"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -34,7 +35,7 @@ def test_build_single_module(tmp_path):
             assert name not in zip_names
 
 
-def test_build_package(tmp_path):
+def test_build_package(tmp_path: Path) -> None:
     with build_fixture_project("demo-package"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -54,7 +55,7 @@ def test_build_package(tmp_path):
         assert "data_out.json" not in zip_names
 
 
-def test_build_src_package(tmp_path):
+def test_build_src_package(tmp_path: Path) -> None:
     with build_fixture_project("demo-src-package"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -70,7 +71,7 @@ def test_build_src_package(tmp_path):
         assert "my_package/data.json" in zip_names
 
 
-def test_build_package_include(tmp_path):
+def test_build_package_include(tmp_path: Path) -> None:
     with build_fixture_project("demo-package-include"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -91,7 +92,7 @@ def test_build_package_include(tmp_path):
         assert "data_out.json" in zip_names
 
 
-def test_namespace_package_by_include(tmp_path):
+def test_namespace_package_by_include(tmp_path: Path) -> None:
     with build_fixture_project("demo-pep420-package"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -107,7 +108,7 @@ def test_namespace_package_by_include(tmp_path):
         assert "foo/my_package/data.json" in zip_names
 
 
-def test_build_explicit_package_dir(tmp_path):
+def test_build_explicit_package_dir(tmp_path: Path) -> None:
     with build_fixture_project("demo-explicit-package-dir"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -123,7 +124,7 @@ def test_build_explicit_package_dir(tmp_path):
         assert "my_package/data.json" in zip_names
 
 
-def test_prepare_metadata(tmp_path):
+def test_prepare_metadata(tmp_path: Path) -> None:
     with build_fixture_project("demo-package"):
         dist_info = api.prepare_metadata_for_build_wheel(tmp_path.as_posix())
         assert dist_info == "demo_package-0.1.0.dist-info"
@@ -132,7 +133,7 @@ def test_prepare_metadata(tmp_path):
 
 
 @pytest.mark.xfail
-def test_build_legacypackage(tmp_path):
+def test_build_legacypackage(tmp_path: Path) -> None:
     with build_fixture_project("demo-legacy"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -152,7 +153,7 @@ def test_build_legacypackage(tmp_path):
         assert "data_out.json" not in zip_names
 
 
-def test_build_package_with_modules_in_src(tmp_path):
+def test_build_package_with_modules_in_src(tmp_path: Path) -> None:
     with build_fixture_project("demo-src-pymodule"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -164,7 +165,7 @@ def test_build_package_with_modules_in_src(tmp_path):
         assert "foo_module.py" in zip_names
 
 
-def test_build_with_cextension(tmp_path):
+def test_build_with_cextension(tmp_path: Path) -> None:
     with build_fixture_project("demo-cextension"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -187,7 +188,7 @@ def test_build_with_cextension(tmp_path):
         ), 'Not collect c files in temporary directory "./build"'
 
 
-def test_build_with_cextension_in_src(tmp_path):
+def test_build_with_cextension_in_src(tmp_path: Path) -> None:
     with build_fixture_project("demo-cextension-in-src"):
         wheel_name = api.build_wheel(tmp_path.as_posix())
         sdist_name = api.build_sdist(tmp_path.as_posix())
@@ -208,7 +209,7 @@ def test_build_with_cextension_in_src(tmp_path):
         ), 'Not collect c files in temporary directory "./build"'
 
 
-def test_build_editable(tmp_path):
+def test_build_editable(tmp_path: Path) -> None:
     with build_fixture_project("demo-package") as project:
         wheel_name = api.build_editable(tmp_path.as_posix())
         assert api.get_requires_for_build_editable() == []
@@ -229,13 +230,13 @@ def test_build_editable(tmp_path):
             assert proxy_module == (
                 "from editables.redirector import RedirectingFinder as F\n"
                 "F.install()\n"
-                "F.map_module('my_package', {0!r})".format(
+                "F.map_module('my_package', {!r})".format(
                     str((project / "my_package" / "__init__.py").resolve())
                 )
             )
 
 
-def test_build_editable_src(tmp_path):
+def test_build_editable_src(tmp_path: Path) -> None:
     with build_fixture_project("demo-src-package-include") as project:
         wheel_name = api.build_editable(tmp_path.as_posix())
 
@@ -253,13 +254,13 @@ def test_build_editable_src(tmp_path):
             assert proxy_module == (
                 "from editables.redirector import RedirectingFinder as F\n"
                 "F.install()\n"
-                "F.map_module('my_package', {0!r})".format(
+                "F.map_module('my_package', {!r})".format(
                     str((project / "sub" / "my_package" / "__init__.py").resolve())
                 )
             )
 
 
-def test_build_editable_pep420(tmp_path):
+def test_build_editable_pep420(tmp_path: Path) -> None:
     with build_fixture_project("demo-pep420-package") as project:
         wheel_name = api.build_editable(tmp_path.as_posix())
 
@@ -275,3 +276,24 @@ def test_build_editable_pep420(tmp_path):
 
             pth_content = zf.read("demo_package.pth").decode("utf-8").strip()
             assert pth_content == str(project.resolve())
+
+
+def test_prepare_metadata_for_editable(tmp_path: Path) -> None:
+    with build_fixture_project("demo-package"):
+        dist_info = api.prepare_metadata_for_build_editable(tmp_path.as_posix())
+        assert dist_info == "demo_package-0.1.0.dist-info"
+        with (tmp_path / dist_info / "METADATA").open("rb") as metadata:
+            deps = email.message_from_binary_file(metadata).get_all("Requires-Dist")
+        assert "editables" in deps
+
+
+def test_build_purelib_project_with_build(tmp_path: Path) -> None:
+    with build_fixture_project("demo-purelib-with-build"):
+        wheel_name = api.build_wheel(tmp_path.as_posix())
+        assert wheel_name == "demo_package-0.1.0-py3-none-any.whl"
+
+        with zipfile.ZipFile(tmp_path / wheel_name) as zf:
+            wheel_metadata = email.message_from_bytes(
+                zf.read("demo_package-0.1.0.dist-info/WHEEL")
+            )
+            assert wheel_metadata["Root-Is-Purelib"] == "True"
